{% extends "admin/shortcuts.html" %}
{% load i18n %}

{% block extra_shortcuts %}
  {{ block.super }}
  <section>
    <h3>{% if change %}{% translate "Change Form" %}{% else %}{% translate "Add Form" %}{% endif %}</h3>
    <dl>
      <dt class="shortcut-description">{% translate "Save and go to change list" %}</dt>
      <dd class="shortcut-keys"><kbd class="alt">Alt</kbd> + <kbd>s</kbd></dd>

      <dt class="shortcut-description">{% translate "Save and add another" %}</dt>
      <dd class="shortcut-keys"><kbd class="alt">Alt</kbd> + <kbd>a</kbd></dd>

      <dt class="shortcut-description">{% translate "Save and continue editing" %}</dt>
      <dd class="shortcut-keys"><kbd class="alt">Alt</kbd> + <kbd>c</kbd></dd>

      {% if change %}
        <dt class="shortcut-description">{% translate "Delete" %}</dt>
        <dd class="shortcut-keys"><kbd class="alt">Alt</kbd> + <kbd>d</kbd></dd>
      {% endif %}
    </dl>
  </section>
{% endblock %}
